/*******************************************************************
 * NGX-DYNAMIC-MATERIAL-TABLE                                      *
 * @description Create fancy and complex tables dynamically        *
 * @file dynamic-table.component.ts                                *
 * @author Gökhan Sari - <goekhan.sari@arpage.ch>                  *
 * @copyright Arpage AG, 2018                                      *
 *******************************************************************/
import { Injector, QueryList } from '@angular/core';
import { Subject } from 'rxjs';
import { AbstractWebLibraryComponent } from '../abstract-web-library.component';
import { DynamicTableDataProvider } from './shared/dynamic-table-data-provider';
import { DynamicTableContainerDirective } from './directives/dynamic-table.directive';
import { DynamicTableOptionInterface } from './interfaces/dynamic-table-option.interface';
import { DynamicTableActionMessageService } from './services/dynamic-table-action-message.service';
import { DynamicTableMouseEventMessageService } from './services/dynamic-table-mouse-event-message.service';
/**
 * Container component which can contain and control multiple table instances.
 *
 * @param selector
 * @param templateUrl
 * @param styleUrls
 * @param animations
 */
export declare class DynamicTableComponent extends AbstractWebLibraryComponent {
    static readonly FILTER_MIN_VALUE: number;
    filterHint: string;
    tableOptions: Array<DynamicTableOptionInterface>;
    palTableDataProvider: DynamicTableDataProvider;
    actionsSubject: Subject<DynamicTableActionMessageService<object>>;
    mouseEventsSubject: Subject<DynamicTableMouseEventMessageService<object>>;
    tablesQueryList: QueryList<DynamicTableContainerDirective>;
    showFilter: boolean;
    /**
     * @inheritdoc
     */
    constructor(injector: Injector);
    /**
     * Triggered when on the filter input field is clicked.
     * @returns void
     */
    onFilterEnter(): void;
    /**
     * Triggered when the user defocusses the filter input field.
     * @returns void
     */
    onFilterLeave(): void;
}
